from os.path import basename, dirname, join, splitext

class Reveal:
    def __init__(self, lines, theme):
        self.html = open(join(dirname(__file__), "..", "template.html"),
                'r').read().replace("---theme---", theme).replace("---section---", str.join(
                    "        ", lines))

    def generate(self, filename, title):
        open(filename, "w").write(self.html.replace("---title---", title))



#!usr/bin/env python

from md import MD
from os.path import basename, isfile, splitext
from reveal import Reveal
import argparse
import sys

def execute(argv=None):
    if argv is None:
        argv = sys.argv[1:] or ['-h']
    parser = argparse.ArgumentParser(description='convert markdown file to reveal.js html page')
    parser.add_argument('markdown_file', help='the markdown file')
    parser.add_argument('-m', '--theme', help='the reveal.js theme')
    parser.add_argument('-t', '--title', help='the html title')
    parser.add_argument('-o', '--outfile', help='output file name')
    args   = parser.parse_args(argv)
    md     = args.markdown_file
    theme  = args.theme or 'black'
    themes = ['beige', 'black', 'blood', 'league', 'moon', 'night', 'serif', 'simple', 'sky', 'solarized', 'white']
    if theme not in themes:
        print theme, "is not a valid theme"
        print "These are the valid themes:", themes
    elif not isfile(md):
        print md, "is not a file."
        exit(1)
    else:
        print "Generating"
        title = args.title or basename(splitext(md)[0])
        out = args.outfile or (title+".html")
        m = MD(md)
        r = Reveal(m.dump_sections(title), theme)
        r.generate(out, title)
        print "Finish, you can find it at [{}]".format(out)

if __name__ == '__main__':
    execute()



#!/usr/bin/python

from setuptools import setup
import os.path

setup(
    name='md2reveal',
    version='1.0.1',
    author='Lirian Su',
    author_email='liriansu@gmail.com',
    url='https://github.com/LKI/md2reveal',
    license='WTFPL',
    description='Converting markdown to reveal.js html page',
    long_description=open('README.rst').read(),
    entry_points={
        'console_scripts': ['md2reveal = md2reveal.cmdline:execute']
    },
    packages=['md2reveal'],
    data_files=['template.html']
)
